@@ -103,9 +103,6 @@ sub deployment_statements {
   my ($schema, $type, $version, $dir, $sqltargs, @rest) = @_;
 
   $sqltargs ||= {};
-  my $quote_char = $self->schema->storage->sql_maker->quote_char;
-  $sqltargs->{quote_table_names} = $quote_char ? 1 : 0;
-  $sqltargs->{quote_field_names} = $quote_char ? 1 : 0;
 
   if (
     ! exists $sqltargs->{producer_args}{oracle_version}
@@ -285,7 +282,7 @@ sub _ping {
 
 sub _dbh_execute {
   #my ($self, $dbh, $sql, $bind, $bind_attrs) = @_;
-  my ($self, $bind) = @_[0,3];
+  my ($self, $sql, $bind) = @_[0,2,3];
 
   # Turn off sth caching for multi-part LOBs. See _prep_for_execute below
   local $self->{disable_sth_caching} = 1 if first {
@@ -300,26 +297,31 @@ sub _dbh_execute {
   return shift->$next(@_)
     if $self->transaction_depth;
 
-  # cheat the blockrunner - we do want to rerun things regardless of outer state
+  # cheat the blockrunner we are just about to create
+  # we do want to rerun things regardless of outer state
   local $self->{_in_do_block};
 
   return DBIx::Class::Storage::BlockRunner->new(
     storage => $self,
-    run_code => $next,
-    run_args => \@_,
     wrap_txn => 0,
     retry_handler => sub {
       # ORA-01003: no statement parsed (someone changed the table somehow,
       # invalidating your cursor.)
-      return 0 if ($_[0]->retried_count or $_[0]->last_exception !~ /ORA-01003/);
-
-      # re-prepare towards new table data
-      if (my $dbh = $_[0]->storage->_dbh) {
-        delete $dbh->{CachedKids}{$_[0]->run_args->[2]};
+      if (
+        $_[0]->failed_attempt_count == 1
+          and
+        $_[0]->last_exception =~ /ORA-01003/
+          and
+        my $dbh = $_[0]->storage->_dbh
+      ) {
+        delete $dbh->{CachedKids}{$sql};
+        return 1;
+      }
+      else {
+        return 0;
       }
-      return 1;
     },
-  )->run;
+  )->run( $next, @_ );
 }
 
 sub _dbh_execute_for_fetch {
@@ -633,7 +635,7 @@ Unfortunately, Oracle doesn't support identifiers over 30 chars in length, so
 the L<DBIx::Class::Relationship> name is shortened and appended with half of an
 MD5 hash.
 
-See L<DBIx::Class::Storage/"relname_to_table_alias">.
+See L<DBIx::Class::Storage::DBI/relname_to_table_alias>.
 
 =cut
 
@@ -644,7 +646,7 @@ sub relname_to_table_alias {
   my $alias = $self->next::method(@_);
 
   # we need to shorten here in addition to the shortening in SQLA itself,
-  # since the final relnames are a crucial for the join optimizer
+  # since the final relnames are crucial for the join optimizer
   return $self->sql_maker->_shorten_identifier($alias);
 }
 
@@ -761,13 +763,16 @@ It uses the same syntax as L<DBIx::Class::ResultSet/order_by>
   # ORDER SIBLINGS BY
   #     firstname ASC
 
-=head1 AUTHOR
+=head1 FURTHER QUESTIONS?
 
-See L<DBIx::Class/AUTHOR> and L<DBIx::Class/CONTRIBUTORS>.
+Check the list of L<additional DBIC resources|DBIx::Class/GETTING HELP/SUPPORT>.
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-You may distribute this code under the same terms as Perl itself.
+This module is free software L<copyright|DBIx::Class/COPYRIGHT AND LICENSE>
+by the L<DBIx::Class (DBIC) authors|DBIx::Class/AUTHORS>. You can
+redistribute it and/or modify it under the same terms as the
+L<DBIx::Class library|DBIx::Class/COPYRIGHT AND LICENSE>.
 
 =cut
 
